from app import arth
import unittest

class TestArithmetic(unittest.TestCase):

    def test_addition(self):
        self.assertEqual(arth.add(1, 2), 3)

    def test_subtraction(self):
        self.assertEqual(arth.subtract(2, 1), 1)

    def test_multiplication(self):
        self.assertEqual(arth.multiply(5, 5), 25)

    def test_division(self):
        self.assertEqual(arth.divide(8, 2), 4)

if __name__ == '__main__':
    unittest.main()


from setuptools import setup, find_packages

setup(
    name='hesham_calculation',
    packages=find_packages(where="app"),
    version='1.0.0',
    description='calculate some items',
    author='Hesham',
    install_requires=[],
    setup_requires=['pytest-runner'],
    tests_require=['pytest==4.4.1'],
    test_suite='tests',
)